@@ -115,7 +115,7 @@ use MARC::Record;
 use MARC::Field;
 use MARC::File::MiJ;
 
-our $VERSION = '1.281';
+our $VERSION = '1.29';
 
 with 'Catmandu::Exporter', 'Catmandu::Exporter::MARC::Base';
 
@@ -131,7 +131,9 @@ sub add {
 
 	my $marc = $self->_raw_to_marc_record($data->{$self->record});
 
-	$self->fh->print(MARC::File::MiJ::encode($marc) . "\n");
+  my $res  = MARC::File::MiJ::encode($marc);
+  utf8::decode($res);
+	$self->fh->print("$res\n");
 }
 
 sub commit {
